@@ -3,6 +3,8 @@ use strict;
 
 package User::Simple::Admin;
 
+=encoding UTF-8
+
 =head1 NAME
 
 User::Simple::Admin - User::Simple user administration
@@ -22,10 +24,11 @@ User::Simple::Admin - User::Simple user administration
   $id = $ua->id($login);
   $login = $ua->login($id);
 
-  $otherattrib = $user->otherattrib;
+  $otherattrib = $user->otherattrib($id);
 
   $ok = $usr->set_login($id, $login);
   $ok = $usr->set_passwd($id, $passwd);
+  $ok = $usr->set_otherattrib($id, $value);
   $ok = $usr->clear_session($id);
 
   $id = $ua->new_user(login => $login, passwd => $passwd, 
@@ -166,7 +169,7 @@ keys).
 Just as with the accessors, if you have extra columns, you can modify them the
 same way:
 
-  $ok = $usr->set_otherattrib($id);
+  $ok = $usr->set_otherattrib($id, $value);
 
 i.e.
 
@@ -196,9 +199,11 @@ Gunnar Wolf <gwolf@gwolf.org>
 
 =head1 COPYRIGHT
 
-Copyright 2005 Gunnar Wolf / Instituto de Investigaciones Econmicas UNAM
-This module is Free Software, it can be redistributed under the same terms
-as Perl.
+Copyright 2005-2009 Gunnar Wolf / Instituto de Investigaciones
+Económicas UNAM 
+
+This module is Free Software; it can be redistributed under the same
+terms as Perl.
 
 =cut
 
@@ -336,7 +341,7 @@ sub dump_users {
 	    # sensitive. Gah, we work around that to provide the much more 
 	    # common lowercase fields... This might still have some problems
 	    # attached, please tell me if it breaks for you.
-	    for my $case qw(id ID Id iD) {
+	    for my $case (qw(id ID Id iD)) {
 		if (exists $row->{$case}) {
 		    $id = $row->{$case};
 		    last;
@@ -379,14 +384,19 @@ sub login {
 # We need only the mutators for the special case fields - Handle everything
 # else via AUTOLOAD
 sub set_login { 
-    my ($self, $id, $new, $sth, $ret);
+    my ($self, $id, $new, $sth, $ret, $used);
     $self = shift;
     $id = shift;
     $new = shift;
 
     return undef unless $id;
 
-    if (my $used = $self->id($new)) {
+    # Setting the login to the current login? Noop doomed to fail, make it look
+    # as a success
+    $used = $self->id($new);
+    return 1 if $used and $used == $self->id($self->login($id));
+
+    if ($used) {
 	carp "The requested login is already used (ID $used).";
 	return undef;
     }
